
.. _`API Reference`:

API Reference
=============

This section describes the external API of the nocaselist project. Any
internal symbols and APIs are omitted.


.. _`Class NocaseList`:

Class NocaseList
----------------

.. autoclass:: nocaselist.NocaseList
   :members:
   :special-members: __getitem__

   .. # Note, we want to exclude __init__. Specifying one other special member
   .. # ba name causes __init__ to be excluded and all other special methods to
   .. # be included.

   .. rubric:: Methods

   .. autoautosummary:: nocaselist.NocaseList
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: nocaselist.NocaseList
      :attributes:

   .. rubric:: Details
